@@ -29,8 +29,13 @@ from .functions_components import (
     export_components,
     get_comp_statistics,
     split_uid,
+    get_all_enabled_comps_from_system,
     )
 
+from .streamlit_functions import (
+    show_mermaid_diagram,
+)
+
 # deprecated functions
 from ._backend_calls import _backend_put, _backend_get, _backend_post
 
