@@ -84,7 +84,7 @@ def _backend_get(endpoint: str) -> dict | str:
 def _backend_GET(
         endpoint: str,
         headers: dict = {"accept": "application/json, application/toml"}
-        ) -> tuple[int, dict | str]:
+        ) -> tuple[int, dict | list | str]:
     """An internal function to make the development of get functions easier.
 
     Params:
@@ -133,7 +133,7 @@ def _backend_POST(
         endpoint: str,
         data: dict,
         headers: dict = {"Content-Type": "application/json", "accept": "application/json"}
-        ) -> tuple[int, dict | str]:
+        ) -> tuple[int, dict | list | str]:
     """An internal function to make the development of posting functions easier.
 
     Params:
@@ -188,7 +188,7 @@ def _backend_PUT(
         endpoint: str,
         data: dict,
         headers: dict = {"Content-Type": "application/json", "accept": "application/json"}
-        ) -> tuple[int, dict | str]:
+        ) -> tuple[int, dict | list | str]:
     """An internal function to make the development of PUT functions/update easier.
 
     Params:
@@ -197,7 +197,7 @@ def _backend_PUT(
         headers(dict | None): headers to include in the request
 
     Returns:
-        dict: html response from the backend
+        dict: response from the backend
     """
 
     endpoint = f"/api{endpoint}" if endpoint not in api_excluded_endpoints else endpoint
