@@ -2,7 +2,7 @@ import uuid
 from anyio import sleep
 from .functions_projects import get_list_of_all_project_infos, get_recent_project
 from ._backend_calls import _backend_GET
-from .functions import move_parameter_placeholder
+from .functions import move_parameter_placeholder, cleanup_parameters
 
 import streamlit as st
 import streamlit_mermaid as stmd
@@ -198,7 +198,7 @@ def st_load_components(uid_list: list[str] = None) -> dict[str, dict]:
 
 
     for component_uid, component in st.session_state['db']['components'].items():
-        st.session_state['db']['components'][component_uid] = move_parameter_placeholder(component)
+        st.session_state['db']['components'][component_uid] = cleanup_parameters(move_parameter_placeholder(component))
     
     return st.session_state['db']['components']
 
